summaryrefslogtreecommitdiffstats
path: root/quanta/project/projectlist.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/project/projectlist.h')
-rw-r--r--quanta/project/projectlist.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/quanta/project/projectlist.h b/quanta/project/projectlist.h
index 505fbfd0..87593daf 100644
--- a/quanta/project/projectlist.h
+++ b/quanta/project/projectlist.h
@@ -26,7 +26,7 @@ class QDomDocument;
/**
@short Container for the project files.
- For fast lookup this container is based on QDict.
+ For fast lookup this container is based on TQDict.
The key is generated without a trailing '/' so it doesn't matter if you
search for a folder in this container with or without trailing '/'
*/
@@ -34,12 +34,12 @@ class QDomDocument;
class ProjectList : public ProjectUrlList
{
public:
/** 1009 is a guess for maximum files in an average project, this number should be prime (@ref QDict)
*/
ProjectList( int size = 1009 );
~ProjectList() {};
- typedef QDictIterator<ProjectURL> Iterator;
+ typedef TQDictIterator<ProjectURL> Iterator;
/** resets @ref m_baseURL */
void clear();
@@ -49,8 +49,8 @@ public:
invalid entries gets removed!
@return true if an old structure was found
*/
- bool readFromXML(QDomDocument &dom, const KURL &baseURL,
- const KURL &templateURL, const QRegExp &excludeRx);
+ bool readFromXML(TQDomDocument &dom, const KURL &baseURL,
+ const KURL &templateURL, const TQRegExp &excludeRx);
/**
@return the relative URL
*/
@@ -93,23 +93,23 @@ private:
private because I want to control the key.
use insert(ProjectURL *url) instead.
*/
- void insert(const QString & key, const ProjectURL * item);
+ void insert(const TQString & key, const ProjectURL * item);
/**
private because I want to control the key.
use find(const KURL &url) instead.
*/
- ProjectURL *find ( const QString & key ) const;
+ ProjectURL *find ( const TQString & key ) const;
/**
private because I want to control the key.
*/
- bool remove ( const QString & key );
+ bool remove ( const TQString & key );
/**
private because I want to control the key.
*/
- void replace(const QString & key, const ProjectURL * item);
+ void replace(const TQString & key, const ProjectURL * item);
};
#endif // PROJECTFILES_H
@@ -34,12 +34,12 @@ class QDomDocument;
{
public:
- /** 1009 is a guess for maximum files in an average project, this number should be prime (@ref QDict)
+ /** 1009 is a guess for maximum files in an average project, this number should be prime (@ref TQDict)
*/
ProjectList( int size = 1009 );